@@ -1,20 +1,27 @@
+# Copyright (c) 2016, moe@busyloop.net
+# All rights reserved.
 #
-# lolcat (c)2011 moe@busyloop.net
+# Redistribution and use in source and binary forms, with or without
+# modification, are permitted provided that the following conditions are met:
+#     * Redistributions of source code must retain the above copyright
+#       notice, this list of conditions and the following disclaimer.
+#     * Redistributions in binary form must reproduce the above copyright
+#       notice, this list of conditions and the following disclaimer in the
+#       documentation and/or other materials provided with the distribution.
+#     * Neither the name of the lolcat nor the
+#       names of its contributors may be used to endorse or promote products
+#       derived from this software without specific prior written permission.
 #
-
-#            DO WHAT THE FUCK YOU WANT TO PUBLIC LICENSE 
-#                    Version 2, December 2004 
-#
-# Copyright (C) 2004 Sam Hocevar <sam@hocevar.net> 
-#
-# Everyone is permitted to copy and distribute verbatim or modified 
-# copies of this license document, and changing it is allowed as long 
-# as the name is changed. 
-#
-#            DO WHAT THE FUCK YOU WANT TO PUBLIC LICENSE 
-#   TERMS AND CONDITIONS FOR COPYING, DISTRIBUTION AND MODIFICATION 
-#
-#  0. You just DO WHAT THE FUCK YOU WANT TO.
+# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
+# ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
+# WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
+# DISCLAIMED. IN NO EVENT SHALL <COPYRIGHT HOLDER> BE LIABLE FOR ANY
+# DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
+# (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
+# LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
+# ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
+# (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
+# SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 require "lolcat/version"
 require "lolcat/lol"
@@ -23,30 +30,6 @@ require 'stringio'
 require 'trollop'
 
 module Lol
-  def self.halp!(text, opts={})
-    opts = { 
-      :animate => false,
-      :duration => 12,
-      :os => 0,
-      :speed => 20,
-      :spread => 8.0,
-      :freq => 0.3
-    }.merge opts
-
-    begin
-      i = 20
-      o = rand(256)
-      text.split("\n").each do |line|
-        i -= 1
-        opts[:os] = o+i
-        Lol.println line, opts
-      end
-      puts "\n"
-    rescue Interrupt
-    end
-    exit 1
-  end
-
   def self.cat!
     p = Trollop::Parser.new do
       version "lolcat #{Lolcat::VERSION} (c)2011 moe@busyloop.net"
@@ -89,15 +72,25 @@ FOOTER
         buf = StringIO.new
         p.educate buf
         buf.rewind
-        halp! buf.read, {}
+        opts = {
+          :animate => false,
+          :duration => 12,
+          :os => rand(256),
+          :speed => 20,
+          :spread => 8.0,
+          :freq => 0.3
+        }
+        Lol.cat buf.read.split("\n"), opts
+        puts
         buf.close
+        exit 1
       end
       o
     end
 
-    p.die :spread, "must be > 0" if opts[:spread] < 0.1
-    p.die :duration, "must be > 0" if opts[:duration] < 0.1
-    p.die :speed, "must be > 0.1" if opts[:speed] < 0.1
+    p.die :spread, "must be >= 0.1" if opts[:spread] < 0.1
+    p.die :duration, "must be >= 0.1" if opts[:duration] < 0.1
+    p.die :speed, "must be >= 0.1" if opts[:speed] < 0.1
 
     opts[:os] = opts[:seed]
     opts[:os] = rand(256) if opts[:os] == 0
